==> gradle-1.11-rc-1-all.zip: gradle-1.11-rc-1/src/diagnostics/org/gradle/api/tasks/diagnostics/internal/graph/nodes/UnresolvedDependencyEdge.java <==
/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.tasks.diagnostics.internal.graph.nodes;

import org.gradle.api.artifacts.component.ComponentSelector;
import org.gradle.api.artifacts.component.ModuleComponentIdentifier;
import org.gradle.api.artifacts.component.ModuleComponentSelector;
import org.gradle.api.artifacts.result.ComponentSelectionReason;
import org.gradle.api.artifacts.result.UnresolvedDependencyResult;
import org.gradle.api.internal.artifacts.component.DefaultModuleComponentIdentifier;

import java.util.Collections;
import java.util.Set;

public class UnresolvedDependencyEdge implements DependencyEdge {
    private final UnresolvedDependencyResult dependency;
    private final ModuleComponentIdentifier actual;

    public UnresolvedDependencyEdge(UnresolvedDependencyResult dependency) {
        this.dependency = dependency;
        ModuleComponentSelector attempted = (ModuleComponentSelector)dependency.getAttempted();
        actual = DefaultModuleComponentIdentifier.newId(attempted.getGroup(), attempted.getModule(), attempted.getVersion());
    }

    public boolean isResolvable() {
        return false;
    }

    public ComponentSelector getRequested() {
        return dependency.getRequested();
    }

    public ModuleComponentIdentifier getActual() {
        return actual;
    }

    public ComponentSelectionReason getReason() {
        return dependency.getAttemptedReason();
    }

    public ModuleComponentIdentifier getFrom() {
        return (ModuleComponentIdentifier)dependency.getFrom().getId();
    }

    public Set<? extends RenderableDependency> getChildren() {
        return Collections.singleton(new InvertedRenderableModuleResult(dependency.getFrom()));
    }
}

==> gradle-2.6-rc-1-all.zip: gradle-2.6-rc-1/src/diagnostics/org/gradle/api/tasks/diagnostics/internal/graph/nodes/UnresolvedDependencyEdge.java <==
/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.tasks.diagnostics.internal.graph.nodes;

import org.gradle.api.artifacts.component.ComponentSelector;
import org.gradle.api.artifacts.component.ModuleComponentIdentifier;
import org.gradle.api.artifacts.component.ModuleComponentSelector;
import org.gradle.api.artifacts.result.ComponentSelectionReason;
import org.gradle.api.artifacts.result.UnresolvedDependencyResult;
import org.gradle.internal.component.external.model.DefaultModuleComponentIdentifier;

import java.util.Collections;
import java.util.Set;

public class UnresolvedDependencyEdge implements DependencyEdge {
    private final UnresolvedDependencyResult dependency;
    private final ModuleComponentIdentifier actual;

    public UnresolvedDependencyEdge(UnresolvedDependencyResult dependency) {
        this.dependency = dependency;
        // TODO:Prezi Is this cast safe? Can't this be a LibraryComponentSelector, say?
        ModuleComponentSelector attempted = (ModuleComponentSelector)dependency.getAttempted();
        actual = DefaultModuleComponentIdentifier.newId(attempted.getGroup(), attempted.getModule(), attempted.getVersion());
    }

    public boolean isResolvable() {
        return false;
    }

    public ComponentSelector getRequested() {
        return dependency.getRequested();
    }

    public ModuleComponentIdentifier getActual() {
        return actual;
    }

    public ComponentSelectionReason getReason() {
        return dependency.getAttemptedReason();
    }

    public ModuleComponentIdentifier getFrom() {
        return (ModuleComponentIdentifier)dependency.getFrom().getId();
    }

    public Set<? extends RenderableDependency> getChildren() {
        return Collections.singleton(new InvertedRenderableModuleResult(dependency.getFrom()));
    }
}
